# https://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when#comment20826625_12429344
# 2012 hadley says "globalVariables is a hideous hack and I will never use it"
# 2014 hadley updates his own answer with globalVariables as one of "two solutions"
#' @importFrom Rcpp evalCpp
#' @useDynLib marginaleffects
#' @import data.table
utils::globalVariables(c(
"marginaleffects_contrast_hi",
"marginaleffects_contrast_lo",
"..bycols",
"..to_keep",
"..cols",
"..idx_by",
"..idx_hi",
"..cl",
"..idx_lo",
".data",
"..idx_or",
"..idx",
"..idx1",
"..idx2",
"..nonfocal",
"rowidcf",
"elast",
"..tmp",
"..variables_grid",
"..w",
"marginaleffects_lab",
"marginaleffects_ter",
".",
"tmp_idx",
"comparison",
"condition_variable",
"conf_int",
"conf_level",
"conf.high",
"conf.low",
"contrast",
"draw",
"dydx",
"eps",
"estimates",
"estimate",
"formatBicLL",
"gn",
"group",
"logLik",
"m",
"marginaleffects_function",
"marginaleffects_wts_internal",
"marginalmean",
"model",
"N",
"p.value",
"part",
"patterns",
"position",
"predicted_hi",
"predicted_lo",
"predicted_or",
"predicted",
"rowid",
"rowidunique",
"section",
"stars_note",
"statistic",
"statistic1",
"std.error",
"term",
"ticks",
"tmp_grp",
"comparison_idx",
"value",
"where",
"wts"))